@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2019-2020 Mike Fährmann
+# Copyright 2019-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -35,6 +35,7 @@ class SexcomExtractor(Extractor):
     def _pagination(self, url):
         while True:
             extr = text.extract_from(self.request(url).text)
+            url = extr('<link rel="next" href="', '"')
 
             while True:
                 href = extr('<a class="image_wrapper" href="', '"')
@@ -42,11 +43,9 @@ class SexcomExtractor(Extractor):
                     break
                 yield self.root + href
 
-            pager = extr('id="pagenum"', '</div>')
-            url = text.extract(pager, ' href="', '"')[0]
             if not url:
                 return
-            url = text.urljoin(self.root, url)
+            url = text.urljoin(self.root, text.unescape(url))
 
     def _parse_pin(self, url):
         response = self.request(url, fatal=False)
@@ -71,18 +70,27 @@ class SexcomExtractor(Extractor):
             info = extr("player.updateSrc(", ");")
 
             if info:
-                path = text.extract(info, "src: '", "'")[0]
-                data["filename"] = path.rpartition("/")[2]
-                data["extension"] = "mp4"
-                if "'HD'" in info:
-                    path += "/hd"
-                data["url"] = self.root + path
+                try:
+                    path, _ = text.rextract(
+                        info, "src: '", "'", info.index("label: 'HD'"))
+                except ValueError:
+                    path = text.extr(info, "src: '", "'")
+                text.nameext_from_url(path, data)
+                data["url"] = path
             else:
+                iframe = extr('<iframe', '>')
+                src = (text.extr(iframe, ' src="', '"') or
+                       text.extr(iframe, " src='", "'"))
+                if not src:
+                    self.log.warning("Unable to fetch media from %s", url)
+                    return None
                 data["extension"] = None
-                data["url"] = "ytdl:" + text.extract(
-                    extr('<iframe', '>'), ' src="', '"')[0]
+                data["url"] = "ytdl:" + src
         else:
-            data["url"] = text.unescape(extr(' src="', '"').partition("?")[0])
+            data["_http_validate"] = _check_empty
+            url = text.unescape(extr(' src="', '"'))
+            data["url"] = url.partition("?")[0]
+            data["_fallback"] = (url,)
             text.nameext_from_url(data["url"], data)
 
         data["uploader"] = extr('itemprop="author">', '<')
@@ -126,7 +134,8 @@ class SexcomPinExtractor(SexcomExtractor):
         }),
         # video
         ("https://www.sex.com/pin/55748341/", {
-            "pattern": "https://www.sex.com/video/stream/776229/hd",
+            "pattern": r"https://cdn\.sex\.com/videos/pinporn"
+                       r"/2018/02/10/776229_hd\.mp4",
             "content": "e1a5834869163e2c4d1ca2677f5b7b367cf8cfff",
         }),
         # pornhub embed
@@ -162,6 +171,27 @@ class SexcomRelatedPinExtractor(SexcomPinExtractor):
         return self._pagination(url)
 
 
+class SexcomPinsExtractor(SexcomExtractor):
+    """Extractor for a user's pins on www.sex.com"""
+    subcategory = "pins"
+    directory_fmt = ("{category}", "{user}")
+    pattern = r"(?:https?://)?(?:www\.)?sex\.com/user/([^/?#]+)/pins/"
+    test = ("https://www.sex.com/user/sirjuan79/pins/", {
+        "count": ">= 15",
+    })
+
+    def __init__(self, match):
+        SexcomExtractor.__init__(self, match)
+        self.user = match.group(1)
+
+    def metadata(self):
+        return {"user": text.unquote(self.user)}
+
+    def pins(self):
+        url = "{}/user/{}/pins/".format(self.root, self.user)
+        return self._pagination(url)
+
+
 class SexcomBoardExtractor(SexcomExtractor):
     """Extractor for pins from a board on www.sex.com"""
     subcategory = "board"
@@ -192,7 +222,7 @@ class SexcomSearchExtractor(SexcomExtractor):
     subcategory = "search"
     directory_fmt = ("{category}", "search", "{search[query]}")
     pattern = (r"(?:https?://)?(?:www\.)?sex\.com/((?:"
-               r"(pic|gif|video)s/([^/?#]+)|search/(pic|gif|video)s"
+               r"(pic|gif|video)s/([^/?#]*)|search/(pic|gif|video)s"
                r")/?(?:\?([^#]+))?)")
     test = (
         ("https://www.sex.com/search/pics?query=ecchi", {
@@ -203,6 +233,7 @@ class SexcomSearchExtractor(SexcomExtractor):
             "range": "1-10",
             "count": 10,
         }),
+        ("https://www.sex.com/pics/?sort=popular&sub=all&page=1"),
     )
 
     def __init__(self, match):
@@ -220,3 +251,7 @@ class SexcomSearchExtractor(SexcomExtractor):
     def pins(self):
         url = "{}/{}".format(self.root, self.path)
         return self._pagination(url)
+
+
+def _check_empty(response):
+    return response.headers.get("content-length") != "0"
